@@ -1,7 +1,4 @@
-use std::{
-    convert::TryFrom,
-    io::{self, Read},
-};
+use std::io::{self, Read};
 
 use super::{virtual_position, VirtualPosition};
 
@@ -26,10 +23,9 @@ impl Block {
     }
 
     /// Returns the unconsumed part of the current block.
-    pub fn fill_buf(&self) -> &[u8] {
+    pub fn buffer(&self) -> &[u8] {
         let start = self.upos as usize;
-        let end = self.ulen() as usize;
-        &self.data[start..end]
+        &self.data[start..]
     }
 
     /// Returns whether the cursor is at the end of the uncompressed data.
